@@ -2,11 +2,16 @@
 # -*- coding: utf-8 -*-
 
 import argparse
+import sys
 
 from spyderml.lib.asciiarts import banner
-from spyderml.lib.utils import spyder_request, treat_objects, soup_tags, soup_comments, soup_attrs
+from spyderml.lib.utils import spyder_request, treat_objects, soup_tags, soup_comments, soup_attrs, get_js, \
+    detect_technologies, update_database
 from spyderml.lib.file import open_file
 
+sys.stdin.reconfigure(encoding='utf-8')
+sys.stdout.reconfigure(encoding='utf-8')
+
 
 class SpyderHtml:
     def __init__(self, args):
@@ -19,20 +24,28 @@ class SpyderHtml:
             targets = open_file(filepath=self.args['file'])
             htmls = []
             for target in targets:
-                htmls.append(spyder_request(target))
-                try:
-                    for html in htmls:
-                        if self.args['tags']:
-                            tags = treat_objects(objects=self.args['tags'])
-                            soup_tags(document=html, object=tags, file=self.args['output'])
-                        elif self.args['comments']:
-                            soup_comments(document=html, file=self.args['output'])
-                        else:
-                            attr = treat_objects(objects=self.args['attribs'])
-                            soup_attrs(document=html, object=attr, file=self.args['output'])
+                if self.args['techs']:
+                    detect_technologies(url=target)
+                else:
+                    htmls.append(spyder_request(target))
+            try:
+                for html in htmls:
+                    if self.args['tags']:
+                        tags = treat_objects(objects=self.args['tags'])
+                        soup_tags(document=html, object=tags, file=self.args['output'])
+                    elif self.args['comments']:
+                        soup_comments(document=html, file=self.args['output'])
+                    elif self.args['getjs']:
+                        get_js(url=self.args['target'], document=html, file=self.args['output'])
+                    else:
+                        attr = treat_objects(objects=self.args['attribs'])
+                        soup_attrs(document=html, object=attr, file=self.args['output'])
 
-                except AttributeError:
-                    pass
+            except AttributeError:
+                pass
+
+        elif self.args['update']:
+            update_database()
 
         else:
             text = spyder_request(target=self.args['target'])
@@ -41,6 +54,10 @@ class SpyderHtml:
                 soup_tags(document=text, object=tags, file=self.args['output'])
             elif self.args['comments']:
                 soup_comments(document=text, file=self.args['output'])
+            elif self.args['getjs']:
+                get_js(url=self.args['target'], document=text, file=self.args['output'])
+            elif self.args['techs']:
+                detect_technologies(url=self.args['target'])
             else:
                 attr = treat_objects(objects=self.args['attribs'])
                 soup_attrs(document=text, object=attr, file=self.args['output'])
@@ -57,6 +74,8 @@ def main():
                                                                "http://example.com/index.html")
     group_target.add_argument('-f', '--file', type=str, help="Parameter that defines target URLs")
 
+    group_target.add_argument('--update',help='Flag responsible for updating the database.',
+                              default=False, action='store_true')
     group_action.add_argument('--tags', type=str, help="Flag that defines which tags the program will bring")
 
     group_action.add_argument('--comments', help="Flag that brings the comments", default=False, action='store_true', )
@@ -64,8 +83,12 @@ def main():
     group_action.add_argument('--attribs', type=str,
                               help="Flag that defines which attributes the application will look for.")
 
+    group_action.add_argument('--getjs', help='Flag that brings all JS files from the page.',
+                              default=False, action='store_true')
+    group_action.add_argument('--techs', help='Flag trying to discover the technologies of the page.',
+                              default=False, action='store_true')
     parser.add_argument('-o', '--output', type=str, help="Flag that defines in which file the command output will be "
-                                                         "saved.")
+                                                        "saved.")
 
     args = vars(parser.parse_args())
 
